@@ -2,19 +2,20 @@
 
 import pprint
 import numpy as np
-from ..proto import onnx_proto
+from onnx import TensorProto
 from ..common._apply_operation import (
     apply_abs, apply_add, apply_cast, apply_concat, apply_clip,
     apply_div, apply_exp, apply_mul, apply_reshape, apply_sub)
 from ..common._topology import Scope, Operator
 from ..common._container import ModelComponentContainer
-from ..common.data_types import guess_numpy_type, Int64TensorType
+from ..common.data_types import (
+    guess_numpy_type, Int64TensorType, guess_proto_type)
 from ..common._registration import register_converter
 from .._supported_operators import sklearn_operator_name_map
 
 
 def _handle_zeros(scope, container, concatenated_prob_name,
-                  reduced_prob_name, n_classes):
+                  reduced_prob_name, n_classes, proto_type):
     """
     This function replaces 0s in concatenated_prob_name with 1s and
     0s in reduced_prob_name with n_classes.
@@ -31,16 +32,20 @@ def _handle_zeros(scope, container, concatenated_prob_name,
     masked_reduced_prob_name = scope.get_unique_variable_name(
         'masked_reduced_prob')
 
-    container.add_initializer(n_classes_name, onnx_proto.TensorProto.FLOAT,
+    proto_type2 = proto_type
+    if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
+        proto_type2 = TensorProto.FLOAT
+
+    container.add_initializer(n_classes_name, proto_type2,
                               [], [n_classes])
 
     apply_cast(scope, reduced_prob_name, cast_prob_name, container,
-               to=onnx_proto.TensorProto.BOOL)
+               to=TensorProto.BOOL)
     container.add_node('Not', cast_prob_name,
                        bool_not_cast_prob_name,
                        name=scope.get_unique_operator_name('Not'))
     apply_cast(scope, bool_not_cast_prob_name, mask_name, container,
-               to=onnx_proto.TensorProto.FLOAT)
+               to=proto_type2)
     apply_add(scope, [concatenated_prob_name, mask_name],
               masked_concatenated_prob_name, container, broadcast=1)
     apply_mul(scope, [mask_name, n_classes_name], reduced_prob_mask_name,
@@ -50,7 +55,7 @@ def _handle_zeros(scope, container, concatenated_prob_name,
     return masked_concatenated_prob_name, masked_reduced_prob_name
 
 
-def _transform_sigmoid(scope, container, model, df_col_name, k):
+def _transform_sigmoid(scope, container, model, df_col_name, k, proto_type):
     """
     Sigmoid Calibration method
     """
@@ -65,12 +70,15 @@ def _transform_sigmoid(scope, container, model, df_col_name, k):
     sigmoid_predict_result_name = scope.get_unique_variable_name(
         'sigmoid_predict_result')
 
-    container.add_initializer(a_name, onnx_proto.TensorProto.FLOAT,
+    proto_type2 = proto_type
+    if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
+        proto_type2 = TensorProto.FLOAT
+
+    container.add_initializer(a_name, proto_type2,
                               [], [model.calibrators_[k].a_])
-    container.add_initializer(b_name, onnx_proto.TensorProto.FLOAT,
+    container.add_initializer(b_name, proto_type2,
                               [], [model.calibrators_[k].b_])
-    container.add_initializer(unity_name, onnx_proto.TensorProto.FLOAT,
-                              [], [1])
+    container.add_initializer(unity_name, proto_type2, [], [1])
 
     apply_mul(scope, [a_name, df_col_name], a_df_prod_name, container,
               broadcast=0)
@@ -84,7 +92,7 @@ def _transform_sigmoid(scope, container, model, df_col_name, k):
     return sigmoid_predict_result_name
 
 
-def _transform_isotonic(scope, container, model, T, k, dtype):
+def _transform_isotonic(scope, container, model, T, k, dtype, proto_type):
     """
     Isotonic calibration method
     This function can only handle one instance at a time because
@@ -124,12 +132,16 @@ def _transform_isotonic(scope, container, model, T, k, dtype):
             "".format(type(model.calibrators_[k]),
                       pprint.pformat(dir(model.calibrators_[k]))))
 
+    proto_type2 = proto_type
+    if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
+        proto_type2 = TensorProto.FLOAT
+
     container.add_initializer(
-        calibrator_x_name, onnx_proto.TensorProto.FLOAT,
+        calibrator_x_name, proto_type2,
         [len(getattr(model.calibrators_[k], atX))],
         getattr(model.calibrators_[k], atX))
     container.add_initializer(
-        calibrator_y_name, onnx_proto.TensorProto.FLOAT,
+        calibrator_y_name, proto_type2,
         [len(getattr(model.calibrators_[k], atY))],
         getattr(model.calibrators_[k], atY))
 
@@ -248,6 +260,10 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
         raise RuntimeError(
             "Option 'nocl' is not implemented for operator '{}'.".format(
                 operator.raw_operator.__class__.__name__))
+    proto_type = guess_proto_type(operator.inputs[0].type)
+    proto_type2 = proto_type
+    if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
+        proto_type2 = TensorProto.FLOAT
     dtype = guess_numpy_type(operator.inputs[0].type)
     if dtype != np.float64:
         dtype = np.float32
@@ -265,7 +281,7 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
     this_operator.inputs = operator.inputs
     label_name = scope.declare_local_variable('label', Int64TensorType())
     df_name = scope.declare_local_variable(
-        'probability_tensor', operator.inputs[0].type.__class__())
+        'uncal_probability', operator.inputs[0].type.__class__())
     this_operator.outputs.append(label_name)
     this_operator.outputs.append(df_name)
     df_inp = df_name.full_name
@@ -280,18 +296,19 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
         prob_name[k] = scope.get_unique_variable_name(
             'prob_{}_c{}'.format(model_index, k))
 
-        container.add_initializer(k_name, onnx_proto.TensorProto.INT64,
-                                  [], [cur_k])
+        container.add_initializer(k_name, TensorProto.INT64, [], [cur_k])
 
         container.add_node(
             'ArrayFeatureExtractor', [df_inp, k_name], df_col_name,
             name=scope.get_unique_operator_name(
                 'CaliAFE_%d_c%d' % (model_index, k)),
             op_domain='ai.onnx.ml')
-        T = (_transform_sigmoid(scope, container, model, df_col_name, k)
-             if model.method == 'sigmoid' else
-             _transform_isotonic(
-            scope, container, model, df_col_name, k, dtype))
+        if model.method == 'sigmoid':
+            T = _transform_sigmoid(scope, container, model, df_col_name, k,
+                                   proto_type)
+        else:
+            T = _transform_isotonic(scope, container, model, df_col_name,
+                                    k, dtype, proto_type)
 
         prob_name[k] = T
         if n_classes == 2:
@@ -306,7 +323,7 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
             'unit_float_tensor%d' % model_index)
 
         container.add_initializer(unit_float_tensor_name,
-                                  onnx_proto.TensorProto.FLOAT, [], [1.0])
+                                  proto_type2, [], [1.0])
 
         apply_sub(scope, [unit_float_tensor_name, prob_name[0]],
                   zeroth_col_name, container, broadcast=1)
@@ -330,14 +347,13 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
                 name=scope.get_unique_operator_name('ReduceSum'))
         else:
             axis_name = scope.get_unique_variable_name('axis')
-            container.add_initializer(
-                axis_name, onnx_proto.TensorProto.INT64, [1], [1])
+            container.add_initializer(axis_name, TensorProto.INT64, [1], [1])
             container.add_node(
                 'ReduceSum', [concatenated_prob_name, axis_name],
                 reduced_prob_name,
                 name=scope.get_unique_operator_name('ReduceSum'))
         num, deno = _handle_zeros(scope, container, concatenated_prob_name,
-                                  reduced_prob_name, n_classes)
+                                  reduced_prob_name, n_classes, proto_type)
         apply_div(scope, [num, deno],
                   calc_prob_name, container, broadcast=1,
                   operator_name=scope.get_unique_variable_name(
@@ -395,13 +411,17 @@ def convert_sklearn_calibrated_classifier_cv(
     op = operator.raw_operator
     classes = op.classes_
     output_shape = (-1,)
-    class_type = onnx_proto.TensorProto.STRING
+    class_type = TensorProto.STRING
+    proto_type = guess_proto_type(operator.inputs[0].type)
+    proto_type2 = proto_type
+    if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
+        proto_type2 = TensorProto.FLOAT
 
     if np.issubdtype(op.classes_.dtype, np.floating):
-        class_type = onnx_proto.TensorProto.INT32
+        class_type = TensorProto.INT32
         classes = classes.astype(np.int32)
     elif np.issubdtype(op.classes_.dtype, np.signedinteger):
-        class_type = onnx_proto.TensorProto.INT32
+        class_type = TensorProto.INT32
     else:
         classes = np.array([s.encode('utf-8') for s in classes])
 
@@ -417,7 +437,7 @@ def convert_sklearn_calibrated_classifier_cv(
     add_result_name = scope.get_unique_variable_name('add_result')
 
     container.add_initializer(classes_name, class_type, classes.shape, classes)
-    container.add_initializer(clf_length_name, onnx_proto.TensorProto.FLOAT,
+    container.add_initializer(clf_length_name, proto_type2,
                               [], [clf_length])
 
     for clf_index, clf in enumerate(op.calibrated_classifiers_):
@@ -438,12 +458,12 @@ def convert_sklearn_calibrated_classifier_cv(
         array_feature_extractor_result_name, op_domain='ai.onnx.ml',
         name=scope.get_unique_operator_name('ArrayFeatureExtractor'))
 
-    if class_type == onnx_proto.TensorProto.INT32:
+    if class_type == TensorProto.INT32:
         apply_reshape(scope, array_feature_extractor_result_name,
                       reshaped_result_name, container,
                       desired_shape=output_shape)
         apply_cast(scope, reshaped_result_name, operator.outputs[0].full_name,
-                   container, to=onnx_proto.TensorProto.INT64)
+                   container, to=TensorProto.INT64)
     else:
         apply_reshape(scope, array_feature_extractor_result_name,
                       operator.outputs[0].full_name, container,
