@@ -9,7 +9,7 @@ import numpy as np
 from sklearn.preprocessing import Binarizer
 from skl2onnx import convert_sklearn
 from skl2onnx.common.data_types import FloatTensorType
-from test_utils import dump_data_and_model
+from test_utils import dump_data_and_model, TARGET_OPSET
 
 
 class TestSklearnBinarizer(unittest.TestCase):
@@ -19,17 +19,13 @@ class TestSklearnBinarizer(unittest.TestCase):
                          [0., 1., -1.]], dtype=np.float32)
         model = Binarizer(threshold=0.5)
         model_onnx = convert_sklearn(
-            model,
-            "scikit-learn binarizer",
+            model, "scikit-learn binarizer",
             [("input", FloatTensorType(data.shape))],
-        )
+            target_opset=TARGET_OPSET)
         self.assertTrue(model_onnx is not None)
         dump_data_and_model(
-            data,
-            model,
-            model_onnx,
-            basename="SklearnBinarizer-SkipDim1",
-        )
+            data, model, model_onnx,
+            basename="SklearnBinarizer-SkipDim1")
 
 
 if __name__ == "__main__":
