@@ -395,7 +395,8 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         model = Binarizer(threshold=0.5)
         model_onnx = convert_sklearn(
             model, "scikit-learn binarizer",
-            [("input", DoubleTensorType(data.shape))])
+            [("input", DoubleTensorType(data.shape))],
+            target_opset=TARGET_OPSET)
         self.assertTrue(model_onnx is not None)
         dump_data_and_model(
             data, model, model_onnx,
@@ -460,7 +461,8 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         model, X_test = _fit_model_pca(PCA(random_state=42))
         model_onnx = convert_sklearn(
             model, initial_types=[
-                ("input", DoubleTensorType([None, X_test.shape[1]]))])
+                ("input", DoubleTensorType([None, X_test.shape[1]]))],
+            target_opset=TARGET_OPSET)
         dump_data_and_model(
             X_test, model, model_onnx,
             basename="SklearnPCADoubleDefault")
