@@ -11,7 +11,7 @@ from sklearn.ensemble import (
     GradientBoostingRegressor
 )
 from sklearn.model_selection import train_test_split
-from onnxruntime import InferenceSession, __version__
+from onnxruntime import InferenceSession, __version__ as ort_version
 from skl2onnx import convert_sklearn
 from skl2onnx.common.data_types import (
     BooleanTensorType,
@@ -19,11 +19,13 @@ from skl2onnx.common.data_types import (
     Int64TensorType,
 )
 from skl2onnx.common.data_types import onnx_built_with_ml
-from test_utils import dump_binary_classification, dump_multiple_classification
-from test_utils import fit_classification_model
-from test_utils import dump_data_and_model, fit_regression_model
+from test_utils import (
+    dump_binary_classification, dump_multiple_classification,
+    fit_classification_model, dump_data_and_model, fit_regression_model,
+    TARGET_OPSET)
 
-THRESHOLD = "0.2.1"
+
+ort_version = ort_version.split('+')[0]
 
 
 class TestSklearnGradientBoostingModels(unittest.TestCase):
@@ -31,7 +33,7 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
-        StrictVersion(__version__) <= StrictVersion(THRESHOLD),
+        StrictVersion(ort_version) <= StrictVersion("0.5.0"),
         reason="Depends on PR #1015 onnxruntime.")
     def test_gradient_boosting_classifier1Deviance(self):
         model = GradientBoostingClassifier(n_estimators=1, max_depth=2)
@@ -43,7 +45,8 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
             if cl is not None:
                 model.init_.class_prior_ = np.array([cl, cl])
             initial_types = [('input', FloatTensorType((None, X.shape[1])))]
-            model_onnx = convert_sklearn(model, initial_types=initial_types)
+            model_onnx = convert_sklearn(model, initial_types=initial_types,
+                                         target_opset=TARGET_OPSET)
             if "Regressor" in str(model_onnx):
                 raise AssertionError(str(model_onnx))
             sess = InferenceSession(model_onnx.SerializeToString())
@@ -59,29 +62,19 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
                         "onnxruntime", str(DataFrame(res[1])),
                         "model", str(model_onnx)]
                 raise AssertionError("\n---\n".join(rows))
-        dump_binary_classification(
-            model, suffix="1Deviance",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('%s')" % THRESHOLD)
+        dump_binary_classification(model, suffix="1Deviance")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     def test_gradient_boosting_classifier3(self):
         model = GradientBoostingClassifier(n_estimators=3)
-        dump_binary_classification(
-            model, suffix="3",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('%s')" % THRESHOLD)
+        dump_binary_classification(model, suffix="3")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     def test_gradient_boosting_classifier_multi(self):
         model = GradientBoostingClassifier(n_estimators=3)
-        dump_multiple_classification(
-            model,
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('%s')" % THRESHOLD,
-        )
+        dump_multiple_classification(model)
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -89,18 +82,13 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
         model, X = fit_classification_model(
             GradientBoostingClassifier(n_estimators=3), 2)
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting classifier",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            model, "gradient boosting classifier",
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingBinaryClassifier",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingBinaryClassifier")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -108,18 +96,13 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
         model, X = fit_classification_model(
             GradientBoostingClassifier(n_estimators=4, init='zero'), 2)
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting classifier",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            model, "gradient boosting classifier",
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingBinaryClassifierInitZero",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingBinaryClassifierInitZero")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -127,18 +110,13 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
         model, X = fit_classification_model(
             GradientBoostingClassifier(n_estimators=4), 5)
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting classifier",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            model, "gradient boosting classifier",
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingMultiClassClassifier",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingMultiClassClassifier")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -147,16 +125,12 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
             GradientBoostingClassifier(n_estimators=4), 5, is_int=True)
         model_onnx = convert_sklearn(
             model, "gradient boosting classifier",
-            [("input", Int64TensorType([None, X.shape[1]]))])
+            [("input", Int64TensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingInt",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingInt")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -165,16 +139,12 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
             GradientBoostingClassifier(n_estimators=4), 5, is_bool=True)
         model_onnx = convert_sklearn(
             model, "gradient boosting classifier",
-            [("input", BooleanTensorType([None, X.shape[1]]))])
+            [("input", BooleanTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingBool",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingBool")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -183,21 +153,14 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
             GradientBoostingClassifier(n_estimators=4), 5)
         options = {id(model): {'raw_scores': True}}
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting classifier",
+            model, "gradient boosting classifier",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options=options,
-        )
+            options=options, target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
+            X, model, model_onnx,
             basename="SklearnGradientBoostingMultiClassDecisionFunction",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-            methods=['predict', 'decision_function'],
-        )
+            methods=['predict', 'decision_function'])
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
@@ -205,128 +168,89 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
         model, X = fit_classification_model(
             GradientBoostingClassifier(n_estimators=4, init='zero'), 4)
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting classifier",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            model, "gradient boosting classifier",
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingMultiClassClassifierInitZero",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingMultiClassClassifierInitZero")
 
     def test_gradient_boosting_regressor_ls_loss(self):
         model, X = fit_regression_model(
             GradientBoostingRegressor(n_estimators=3, loss="ls"))
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting regression",
+            model, "gradient boosting regression",
             [("input", FloatTensorType([None, X.shape[1]]))],
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingRegressionLsLoss",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingRegressionLsLoss")
 
     def test_gradient_boosting_regressor_lad_loss(self):
         model, X = fit_regression_model(
             GradientBoostingRegressor(n_estimators=3, loss="lad"))
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting regression",
+            model, "gradient boosting regression",
             [("input", FloatTensorType([None, X.shape[1]]))],
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingRegressionLadLoss",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingRegressionLadLoss")
 
     def test_gradient_boosting_regressor_huber_loss(self):
         model, X = fit_regression_model(
             GradientBoostingRegressor(n_estimators=3, loss="huber"))
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting regression",
+            model, "gradient boosting regression",
             [("input", FloatTensorType([None, X.shape[1]]))],
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingRegressionHuberLoss",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingRegressionHuberLoss")
 
     def test_gradient_boosting_regressor_quantile_loss(self):
         model, X = fit_regression_model(
             GradientBoostingRegressor(n_estimators=3, loss="quantile"))
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting regression",
+            model, "gradient boosting regression",
             [("input", FloatTensorType([None, X.shape[1]]))],
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingRegressionQuantileLoss",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingRegressionQuantileLoss")
 
     def test_gradient_boosting_regressor_int(self):
         model, X = fit_regression_model(
             GradientBoostingRegressor(random_state=42), is_int=True)
         model_onnx = convert_sklearn(
             model, "gradient boosting regression",
-            [("input", Int64TensorType([None, X.shape[1]]))])
+            [("input", Int64TensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingRegressionInt-Dec3",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingRegressionInt-Dec3")
 
     def test_gradient_boosting_regressor_zero_init(self):
         model, X = fit_regression_model(
             GradientBoostingRegressor(n_estimators=30, init="zero",
                                       random_state=42))
         model_onnx = convert_sklearn(
-            model,
-            "gradient boosting regression",
+            model, "gradient boosting regression",
             [("input", FloatTensorType([None, X.shape[1]]))],
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnGradientBoostingRegressionZeroInit-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnGradientBoostingRegressionZeroInit-Dec4")
 
     @unittest.skipIf(
-        StrictVersion(__version__) <= StrictVersion(THRESHOLD),
+        StrictVersion(ort_version) <= StrictVersion("0.5.0"),
         reason="Depends on PR #1015 onnxruntime.")
     def test_gradient_boosting_regressor_learning_rate(self):
         X, y = make_classification(
@@ -335,7 +259,8 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
             X, y, test_size=0.5, random_state=42)
         model = GradientBoostingClassifier().fit(X_train, y_train)
         onnx_model = convert_sklearn(
-            model, 'lr2', [('input', FloatTensorType(X_test.shape))])
+            model, 'lr2', [('input', FloatTensorType(X_test.shape))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(onnx_model.SerializeToString())
         res = sess.run(None, input_feed={'input': X_test.astype(np.float32)})
         r1 = np.mean(
@@ -350,13 +275,12 @@ class TestSklearnGradientBoostingModels(unittest.TestCase):
             GradientBoostingRegressor(random_state=42), is_bool=True)
         model_onnx = convert_sklearn(
             model, "gradient boosting regressor",
-            [("input", BooleanTensorType([None, X.shape[1]]))])
+            [("input", BooleanTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnGradientBoostingRegressorBool-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')")
+            basename="SklearnGradientBoostingRegressorBool-Dec4")
 
 
 if __name__ == "__main__":
