@@ -5,7 +5,7 @@ import unittest
 from distutils.version import StrictVersion
 import numpy
 from numpy.testing import assert_almost_equal
-from onnxruntime import InferenceSession
+from onnxruntime import InferenceSession, __version__ as ort_version
 import sklearn
 from sklearn.datasets import (
     load_iris, make_regression, make_classification,
@@ -18,6 +18,12 @@ from sklearn.ensemble import (
 )
 from sklearn.decomposition import PCA
 from sklearn.pipeline import Pipeline
+try:
+    # scikit-learn >= 0.22
+    from sklearn.utils._testing import ignore_warnings
+except ImportError:
+    # scikit-learn < 0.22
+    from sklearn.utils.testing import ignore_warnings
 from skl2onnx.common.data_types import (
     BooleanTensorType,
     FloatTensorType,
@@ -62,30 +68,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
                      reason="Requires ONNX-ML extension.")
     def test_random_forest_classifier(self):
         model = RandomForestClassifier(n_estimators=3)
-        dump_one_class_classification(
-            model,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')"
-                          " or StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-        )
-        dump_binary_classification(
-            model,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')"
-                          " or StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-        )
-        dump_multiple_classification(
-            model,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2')"
-                          " or StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-        )
+        dump_one_class_classification(model)
+        dump_binary_classification(model)
+        dump_multiple_classification(model)
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_classifier_mismatched_estimator_counts(self):
         model = RandomForestClassifier(n_estimators=3)
         X = [[0, 1], [1, 1], [2, 0]]
@@ -97,7 +86,8 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model.n_estimators += 1
         model_onnx, prefix = convert_model(model, 'binary classifier',
                                            [('input',
-                                             FloatTensorType([None, 2]))])
+                                             FloatTensorType([None, 2]))],
+                                           target_opset=TARGET_OPSET)
         dump_data_and_model(X, model, model_onnx,
                             basename=prefix + "Bin" +
                             model.__class__.__name__ +
@@ -105,6 +95,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_regressor_mismatches(self):
         iris = load_iris()
         X, y = iris.data, iris.target
@@ -116,7 +107,8 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         clr.fit(X, y)
         model_onnx, prefix = convert_model(clr, 'reg',
                                            [('input',
-                                             FloatTensorType([None, 4]))])
+                                             FloatTensorType([None, 4]))],
+                                           target_opset=TARGET_OPSET)
         dump_data_and_model(X_test, clr, model_onnx,
                             basename=prefix + "RegMis" +
                             clr.__class__.__name__ +
@@ -124,19 +116,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_regressor(self):
         model = RandomForestRegressor(n_estimators=3)
-        dump_single_regression(
-            model,
-            allow_failure=("StrictVersion(onnxruntime.__version__)"
-                           " <= StrictVersion('0.2.1')"),
-        )
-        dump_multiple_regression(
-            model,
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-        )
+        dump_single_regression(model)
+        dump_multiple_regression(model)
 
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_regressor_mismatched_estimator_counts(self):
         model = RandomForestRegressor(n_estimators=3)
         X = [[0, 1], [1, 1], [2, 0]]
@@ -148,7 +134,8 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model.n_estimators += 1
         model_onnx, prefix = convert_model(model, 'single regressor',
                                            [('input',
-                                             FloatTensorType([None, 2]))])
+                                             FloatTensorType([None, 2]))],
+                                           target_opset=TARGET_OPSET)
         dump_data_and_model(X, model, model_onnx,
                             basename=prefix + "Reg" +
                             model.__class__.__name__ +
@@ -156,79 +143,51 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_extra_trees_classifier(self):
         model = ExtraTreesClassifier(n_estimators=3)
-        dump_one_class_classification(
-            model,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2') or "
-                          "StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-        )
-        dump_binary_classification(
-            model,
-            allow_failure=(
-                "StrictVersion(onnx.__version__) < StrictVersion('1.2') or "
-                "StrictVersion(onnxruntime.__version__)"
-                " <= StrictVersion('0.2.1')"
-            ),
-        )
-        dump_multiple_classification(
-            model,
-            # Operator cast-1 is not implemented in onnxruntime
-            allow_failure=(
-                "StrictVersion(onnx.__version__) < StrictVersion('1.2') or "
-                "StrictVersion(onnxruntime.__version__)"
-                " <= StrictVersion('0.2.1')"
-            ),
-        )
+        dump_one_class_classification(model)
+        dump_binary_classification(model)
+        dump_multiple_classification(model)
 
+    @ignore_warnings(category=FutureWarning)
     def test_extra_trees_regressor(self):
         model = ExtraTreesRegressor(n_estimators=3)
-        dump_single_regression(
-            model,
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-        )
-        dump_multiple_regression(
-            model,
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')")
+        dump_single_regression(model)
+        dump_multiple_regression(model)
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_model_multi_class_nocl(self):
         model, X = fit_classification_model(
             RandomForestClassifier(random_state=42),
             2, label_string=True)
         model_onnx = convert_sklearn(
-            model,
-            "multi-class nocl",
+            model, "multi-class nocl",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options={id(model): {'nocl': True, 'zipmap': False}})
+            options={id(model): {'nocl': True, 'zipmap': False}},
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         sonx = str(model_onnx)
         assert 'classlabels_strings' not in sonx
         assert 'cl0' not in sonx
         dump_data_and_model(
             X[:5], model, model_onnx, classes=model.classes_,
-            basename="SklearnRFMultiNoCl", verbose=False,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2') or "
-                          "StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')")
+            basename="SklearnRFMultiNoCl")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_model_multi_class_nocl_all(self):
         model, X = fit_classification_model(
             RandomForestClassifier(random_state=42),
             2, label_string=True)
         model_onnx = convert_sklearn(
-            model,
-            "multi-class nocl",
+            model, "multi-class nocl",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options={id(model): {'nocl': True, 'zipmap': False}})
+            options={id(model): {'nocl': True, 'zipmap': False}},
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         sonx = str(model_onnx)
         assert 'classlabels_strings' not in sonx
@@ -250,6 +209,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
             # That explains why the test allows less than 3 differences.
             assert_almost_equal(exp_label, got[0])
 
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_classifier_int(self):
         model, X = fit_classification_model(
             RandomForestClassifier(n_estimators=5, random_state=42),
@@ -257,18 +217,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "random forest classifier",
             [("input", Int64TensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnRandomForestClassifierInt",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnRandomForestClassifierInt")
 
+    @ignore_warnings(category=FutureWarning)
     def test_extra_trees_classifier_int(self):
         model, X = fit_classification_model(
             ExtraTreesClassifier(n_estimators=5, random_state=42),
@@ -276,18 +231,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "extra trees classifier",
             [("input", Int64TensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnExtraTreesClassifierInt",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnExtraTreesClassifierInt")
 
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_classifier_bool(self):
         model, X = fit_classification_model(
             RandomForestClassifier(n_estimators=5, random_state=42),
@@ -295,18 +245,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "random forest classifier",
             [("input", BooleanTensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnRandomForestClassifierBool",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnRandomForestClassifierBool")
 
+    @ignore_warnings(category=FutureWarning)
     def test_extra_trees_classifier_bool(self):
         model, X = fit_classification_model(
             ExtraTreesClassifier(n_estimators=5, random_state=42),
@@ -314,18 +259,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "extra trees regression",
             [("input", BooleanTensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnExtraTreesClassifierBool",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnExtraTreesClassifierBool")
 
+    @ignore_warnings(category=FutureWarning)
     def common_test_model_hgb_regressor(self, add_nan=False):
         model = HistGradientBoostingRegressor(max_iter=5, max_depth=2)
         X, y = make_regression(n_features=10, n_samples=1000,
@@ -340,21 +280,21 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model.fit(X_train, y_train)
 
         model_onnx = convert_sklearn(
-            model, "unused", [("input", FloatTensorType([None, X.shape[1]]))])
+            model, "unused", [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         X_test = X_test.astype(numpy.float32)[:5]
         dump_data_and_model(
             X_test, model, model_onnx,
-            basename="SklearnHGBRegressor", verbose=False,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2') or "
-                          "StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')")
+            basename="SklearnHGBRegressor", verbose=False)
 
     @unittest.skipIf(_sklearn_version() < StrictVersion('0.22.0'),
                      reason="missing_go_to_left is missing")
     @unittest.skipIf(HistGradientBoostingRegressor is None,
                      reason="scikit-learn 0.22 + manual activation")
+    @unittest.skipIf(StrictVersion(ort_version) < StrictVersion('1.2.0'),
+                     reason="issue with nan for earlier ort")
+    @ignore_warnings(category=FutureWarning)
     def test_model_hgb_regressor_nonan(self):
         self.common_test_model_hgb_regressor(False)
 
@@ -362,6 +302,9 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
                      reason="NaN not allowed")
     @unittest.skipIf(HistGradientBoostingRegressor is None,
                      reason="scikit-learn 0.22 + manual activation")
+    @unittest.skipIf(StrictVersion(ort_version) < StrictVersion('1.2.0'),
+                     reason="issue with nan for earlier ort")
+    @ignore_warnings(category=FutureWarning)
     def test_model_hgb_regressor_nan(self):
         self.common_test_model_hgb_regressor(True)
 
@@ -380,7 +323,8 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model.fit(X_train, y_train)
 
         model_onnx = convert_sklearn(
-            model, "unused", [("input", FloatTensorType([None, X.shape[1]]))])
+            model, "unused", [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         X_test = X_test.astype(numpy.float32)[:5]
 
@@ -388,17 +332,14 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
             X_test, model, model_onnx,
             basename="SklearnHGBClassifier%s%d" % (
                 "nan" if add_nan else '', n_classes),
-            verbose=False,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2') or "
-                          "StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')")
+            verbose=False)
 
         if n_classes == 2:
             model_onnx = convert_sklearn(
                 model, "unused",
                 [("input", FloatTensorType([None, X.shape[1]]))],
-                options={model.__class__: {'raw_scores': True}})
+                options={model.__class__: {'raw_scores': True}},
+                target_opset=TARGET_OPSET)
             self.assertIsNotNone(model_onnx)
             X_test = X_test.astype(numpy.float32)[:5]
 
@@ -409,16 +350,15 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
                 basename="SklearnHGBClassifierRaw%s%d" % (
                     "nan" if add_nan else '', n_classes),
                 verbose=False,
-                allow_failure="StrictVersion(onnx.__version__)"
-                              " < StrictVersion('1.2') or "
-                              "StrictVersion(onnxruntime.__version__)"
-                              " < StrictVersion('1.2.0')",
                 methods=['predict', 'decision_function_binary'])
 
     @unittest.skipIf(_sklearn_version() < StrictVersion('0.22.0'),
                      reason="missing_go_to_left is missing")
     @unittest.skipIf(HistGradientBoostingClassifier is None,
                      reason="scikit-learn 0.22 + manual activation")
+    @unittest.skipIf(StrictVersion(ort_version) < StrictVersion('1.2.0'),
+                     reason="issue with nan for earlier ort")
+    @ignore_warnings(category=FutureWarning)
     def test_model_hgb_classifier_nonan(self):
         self.common_test_model_hgb_classifier(False)
 
@@ -426,6 +366,9 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
                      reason="NaN not allowed")
     @unittest.skipIf(HistGradientBoostingClassifier is None,
                      reason="scikit-learn 0.22 + manual activation")
+    @unittest.skipIf(StrictVersion(ort_version) < StrictVersion('1.2.0'),
+                     reason="issue with nan for earlier ort")
+    @ignore_warnings(category=FutureWarning)
     def test_model_hgb_classifier_nan(self):
         self.common_test_model_hgb_classifier(True)
 
@@ -433,6 +376,9 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
                      reason="missing_go_to_left is missing")
     @unittest.skipIf(HistGradientBoostingClassifier is None,
                      reason="scikit-learn 0.22 + manual activation")
+    @unittest.skipIf(StrictVersion(ort_version) < StrictVersion('1.2.0'),
+                     reason="issue with nan for earlier ort")
+    @ignore_warnings(category=FutureWarning)
     def test_model_hgb_classifier_nonan_multi(self):
         self.common_test_model_hgb_classifier(False, n_classes=3)
 
@@ -440,109 +386,83 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
                      reason="NaN not allowed")
     @unittest.skipIf(HistGradientBoostingClassifier is None,
                      reason="scikit-learn 0.22 + manual activation")
+    @ignore_warnings(category=FutureWarning)
     def test_model_hgb_classifier_nan_multi(self):
         self.common_test_model_hgb_classifier(True, n_classes=3)
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_model_random_forest_classifier_multilabel(self):
         model, X_test = fit_multilabel_classification_model(
             RandomForestClassifier(random_state=42, n_estimators=5))
         options = {id(model): {'zipmap': False}}
         model_onnx = convert_sklearn(
-            model,
-            "scikit-learn RandomForestClassifier",
+            model, "scikit-learn RandomForestClassifier",
             [("input", FloatTensorType([None, X_test.shape[1]]))],
-            options=options,
-            target_opset=TARGET_OPSET
-        )
+            options=options, target_opset=TARGET_OPSET)
         self.assertTrue(model_onnx is not None)
         assert 'zipmap' not in str(model_onnx).lower()
         dump_data_and_model(
-            X_test,
-            model,
-            model_onnx,
-            basename="SklearnRandomForestClassifierMultiLabel-Out0",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X_test, model, model_onnx,
+            basename="SklearnRandomForestClassifierMultiLabel-Out0")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_model_random_forest_classifier_multilabel_low_samples(self):
         model, X_test = fit_multilabel_classification_model(
             RandomForestClassifier(random_state=42, n_estimators=5),
             n_samples=4)
         options = {id(model): {'zipmap': False}}
         model_onnx = convert_sklearn(
-            model,
-            "scikit-learn RandomForestClassifier",
+            model, "scikit-learn RandomForestClassifier",
             [("input", FloatTensorType([None, X_test.shape[1]]))],
-            options=options,
-            target_opset=TARGET_OPSET
-        )
+            options=options, target_opset=TARGET_OPSET)
         self.assertTrue(model_onnx is not None)
         assert 'zipmap' not in str(model_onnx).lower()
         dump_data_and_model(
-            X_test,
-            model,
-            model_onnx,
-            basename="SklearnRandomForestClassifierMultiLabelLowSamples-Out0",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X_test, model, model_onnx,
+            basename="SklearnRandomForestClassifierMultiLabelLowSamples-Out0")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_model_extra_trees_classifier_multilabel(self):
         model, X_test = fit_multilabel_classification_model(
             ExtraTreesClassifier(random_state=42, n_estimators=5))
         options = {id(model): {'zipmap': False}}
         model_onnx = convert_sklearn(
-            model,
-            "scikit-learn ExtraTreesClassifier",
+            model, "scikit-learn ExtraTreesClassifier",
             [("input", FloatTensorType([None, X_test.shape[1]]))],
-            options=options,
-            target_opset=TARGET_OPSET
-        )
+            options=options, target_opset=TARGET_OPSET)
         self.assertTrue(model_onnx is not None)
         assert 'zipmap' not in str(model_onnx).lower()
         dump_data_and_model(
-            X_test,
-            model,
-            model_onnx,
-            basename="SklearnExtraTreesClassifierMultiLabel-Out0",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X_test, model, model_onnx,
+            basename="SklearnExtraTreesClassifierMultiLabel-Out0")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_model_extra_trees_classifier_multilabel_low_samples(self):
         model, X_test = fit_multilabel_classification_model(
             ExtraTreesClassifier(random_state=42, n_estimators=5),
             n_samples=10)
         options = {id(model): {'zipmap': False}}
         model_onnx = convert_sklearn(
-            model,
-            "scikit-learn ExtraTreesClassifier",
+            model, "scikit-learn ExtraTreesClassifier",
             [("input", FloatTensorType([None, X_test.shape[1]]))],
-            options=options,
-            target_opset=TARGET_OPSET
-        )
+            options=options, target_opset=TARGET_OPSET)
         self.assertTrue(model_onnx is not None)
         assert 'zipmap' not in str(model_onnx).lower()
         dump_data_and_model(
-            X_test,
-            model,
-            model_onnx,
-            basename="SklearnExtraTreesClassifierMultiLabelLowSamples-Out0",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X_test, model, model_onnx,
+            basename="SklearnExtraTreesClassifierMultiLabelLowSamples-Out0")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
+    @ignore_warnings(category=FutureWarning)
     def test_boston_pca_rf(self):
         data = load_boston()
         X, y = data.data, data.target
@@ -550,20 +470,15 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
             X, y, random_state=0)
         pipe = Pipeline([
             ('acp', PCA(n_components=7)),
-            ('rf', RandomForestRegressor())
-        ])
+            ('rf', RandomForestRegressor())])
         pipe.fit(X_train, y_train)
         X32 = X_test.astype(numpy.float32)
         model_onnx = to_onnx(pipe, X32[:1], target_opset=TARGET_OPSET)
-
         dump_data_and_model(
-            X32, pipe,
-            model_onnx, methods=['predict'],
-            basename="SklearnBostonPCARF-Dec4",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X32, pipe, model_onnx, methods=['predict'],
+            basename="SklearnBostonPCARF-Dec4")
 
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_regressor_int(self):
         model, X = fit_regression_model(
             RandomForestRegressor(n_estimators=5, random_state=42),
@@ -571,18 +486,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "random forest regression",
             [("input", Int64TensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnRandomForestRegressorInt-Dec4",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnRandomForestRegressorInt-Dec4",)
 
+    @ignore_warnings(category=FutureWarning)
     def test_extra_trees_regressor_int(self):
         model, X = fit_regression_model(
             ExtraTreesRegressor(n_estimators=5, random_state=42),
@@ -593,14 +503,10 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
             target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnExtraTreesRegressorInt-Dec4",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnExtraTreesRegressorInt-Dec4")
 
+    @ignore_warnings(category=FutureWarning)
     def test_random_forest_regressor_bool(self):
         model, X = fit_regression_model(
             RandomForestRegressor(n_estimators=5, random_state=42),
@@ -608,18 +514,13 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "random forest regression",
             [("input", BooleanTensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnRandomForestRegressorBool-Dec4",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnRandomForestRegressorBool-Dec4")
 
+    @ignore_warnings(category=FutureWarning)
     def test_extra_trees_regressor_bool(self):
         model, X = fit_regression_model(
             ExtraTreesRegressor(n_estimators=5, random_state=42),
@@ -627,21 +528,16 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "extra trees regression",
             [("input", BooleanTensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET,
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnExtraTreesRegressorBool-Dec4",
-            allow_failure="StrictVersion("
-            "onnxruntime.__version__) <= StrictVersion('0.2.1')",
-        )
+            X, model, model_onnx,
+            basename="SklearnExtraTreesRegressorBool-Dec4")
 
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_randomforestregressor_decision_path(self):
         model = RandomForestRegressor(max_depth=2, n_estimators=2)
         X, y = make_classification(10, n_features=4, random_state=42)
@@ -664,6 +560,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_extratreesregressor_decision_path(self):
         model = ExtraTreesRegressor(max_depth=2, n_estimators=2)
         X, y = make_classification(10, n_features=4, random_state=42)
@@ -686,6 +583,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_randomforestclassifier_decision_path(self):
         model = RandomForestClassifier(max_depth=2, n_estimators=2)
         X, y = make_classification(3, n_features=4, random_state=42)
@@ -710,6 +608,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_extratreesclassifier_decision_path(self):
         model = ExtraTreesClassifier(max_depth=2, n_estimators=3)
         X, y = make_classification(10, n_features=4, random_state=42)
@@ -734,6 +633,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_rf_regressor_decision_leaf(self):
         model = RandomForestRegressor(n_estimators=2, max_depth=3)
         X, y = make_regression(10, n_features=4, random_state=42)
@@ -744,6 +644,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
             model, initial_types=initial_types,
             options={id(model): {'decision_leaf': True}},
             target_opset=TARGET_OPSET)
+
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X.astype(numpy.float32)})
         pred = model.predict(X)
@@ -755,6 +656,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_rf_regressor_decision_path_leaf(self):
         model = RandomForestRegressor(n_estimators=3, max_depth=3)
         X, y = make_regression(10, n_features=4, random_state=42)
@@ -780,6 +682,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_rf_classifier_decision_leaf(self):
         model = RandomForestClassifier(n_estimators=2, max_depth=3)
         X, y = make_classification(3, n_features=4, random_state=42)
@@ -801,6 +704,7 @@ class TestSklearnTreeEnsembleModels(unittest.TestCase):
     @unittest.skipIf(not onnx_built_with_ml(),
                      reason="Requires ONNX-ML extension.")
     @unittest.skipIf(TARGET_OPSET < 12, reason="LabelEncoder")
+    @ignore_warnings(category=FutureWarning)
     def test_rf_classifier_decision_path_leaf(self):
         model = RandomForestClassifier(n_estimators=3, max_depth=3)
         X, y = make_classification(3, n_features=4, random_state=42)
