@@ -28,6 +28,9 @@ from test_utils import (
     dump_data_and_model, fit_regression_model, TARGET_OPSET)
 
 
+ort_version = ort_version.split('+')[0]
+
+
 class TestSklearnSVM(unittest.TestCase):
 
     def _fit_binary_classification(self, model):
@@ -106,13 +109,8 @@ class TestSklearnSVM(unittest.TestCase):
             },
         )
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnBinSVCLinearPF-NoProbOpp",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnBinSVCLinearPF-NoProbOpp")
         model_onnx = convert_sklearn(
             model, "SVC", [("input", FloatTensorType([None, X.shape[1]]))],
             options={id(model): {'zipmap': False}},
@@ -120,13 +118,8 @@ class TestSklearnSVM(unittest.TestCase):
         nodes = model_onnx.graph.node
         self.assertIsNotNone(nodes)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnBinSVCLinearPF-NoProbOpp",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnBinSVCLinearPF-NoProbOpp")
 
     def test_convert_svc_binary_linear_ptrue(self):
         model, X = self._fit_binary_classification(
@@ -152,13 +145,8 @@ class TestSklearnSVM(unittest.TestCase):
             },
         )
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnBinSVCLinearPT",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnBinSVCLinearPT")
 
     def test_convert_svc_multi_linear_pfalse(self):
         model, X = self._fit_multi_classification(
@@ -180,9 +168,7 @@ class TestSklearnSVM(unittest.TestCase):
 
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnMclSVCLinearPF-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')")
+            basename="SklearnMclSVCLinearPF-Dec4")
 
     @unittest.skipIf(apply_less is None, reason="onnxconverter-common old")
     def test_convert_svc_multi_linear_pfalse_ovr(self):
@@ -194,9 +180,7 @@ class TestSklearnSVM(unittest.TestCase):
             target_opset=TARGET_OPSET)
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnMclSVCOVR-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')")
+            basename="SklearnMclSVCOVR-Dec4")
 
     def test_convert_svc_multi_linear_ptrue(self):
         model, X = self._fit_multi_classification(
@@ -216,9 +200,7 @@ class TestSklearnSVM(unittest.TestCase):
                 "vectors_per_class": None})
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnMclSVCLinearPT-Dec2",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')")
+            basename="SklearnMclSVCLinearPT-Dec2")
 
     @unittest.skipIf(
         StrictVersion(ort_version) <= StrictVersion("0.4.0"),
@@ -241,9 +223,7 @@ class TestSklearnSVM(unittest.TestCase):
                 "support_vectors": None,
             },
         )
-        dump_data_and_model(X,
-                            model,
-                            model_onnx,
+        dump_data_and_model(X, model, model_onnx,
                             basename="SklearnRegSVRLinear-Dec3")
 
     def test_convert_nusvc_binary_pfalse(self):
@@ -268,13 +248,8 @@ class TestSklearnSVM(unittest.TestCase):
             },
         )
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnBinNuSVCPF-NoProbOpp",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnBinNuSVCPF-NoProbOpp")
 
     @unittest.skipIf(
         StrictVersion(ort_version) <= StrictVersion("0.4.0"),
@@ -300,13 +275,8 @@ class TestSklearnSVM(unittest.TestCase):
             },
         )
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnBinNuSVCPT",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnBinNuSVCPT")
 
     def test_convert_nusvc_multi_pfalse(self):
         model, X = self._fit_multi_classification(
@@ -332,9 +302,7 @@ class TestSklearnSVM(unittest.TestCase):
         )
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnMclNuSVCPF-Dec1",  # max relative error is 1e-5
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')")
+            basename="SklearnMclNuSVCPF-Dec1")
 
     def test_convert_svc_multi_pfalse_4(self):
         model, X = self._fit_multi_classification(
@@ -346,13 +314,8 @@ class TestSklearnSVM(unittest.TestCase):
         nodes = model_onnx.graph.node
         self.assertIsNotNone(nodes)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnMcSVCPF",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnMcSVCPF")
 
     @unittest.skipIf(_scikit_learn_before_022(),
                      reason="break_ties introduced after 0.22")
@@ -367,9 +330,7 @@ class TestSklearnSVM(unittest.TestCase):
         dump_data_and_model(
             X.astype(numpy.float32),
             model, model_onnx,
-            basename="SklearnMcSVCPFBTF-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')")
+            basename="SklearnMcSVCPFBTF-Dec4")
 
     def test_convert_svc_multi_ptrue_4(self):
         model, X = self._fit_multi_classification(SVC(probability=True), 4)
@@ -379,13 +340,8 @@ class TestSklearnSVM(unittest.TestCase):
         nodes = model_onnx.graph.node
         self.assertIsNotNone(nodes)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnMcSVCPF4-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnMcSVCPF4-Dec4")
 
     def test_convert_nusvc_multi_ptrue(self):
         model, X = self._fit_multi_classification(
@@ -409,13 +365,8 @@ class TestSklearnSVM(unittest.TestCase):
             },
         )
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnMclNuSVCPT-Dec3",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.4.0')"
-        )
+            X, model, model_onnx,
+            basename="SklearnMclNuSVCPT-Dec3")
 
     @unittest.skipIf(
         StrictVersion(ort_version) <= StrictVersion("0.4.0"),
@@ -456,77 +407,48 @@ class TestSklearnSVM(unittest.TestCase):
         model, X = fit_regression_model(
             SVR(), is_int=True)
         model_onnx = convert_sklearn(
-            model,
-            "SVR",
+            model, "SVR",
             [("input", Int64TensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnSVRInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnSVRInt-Dec4")
 
     def test_convert_nusvr_int(self):
         model, X = fit_regression_model(
             NuSVR(), is_int=True)
         model_onnx = convert_sklearn(
-            model,
-            "NuSVR",
-            [("input", Int64TensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET
-        )
+            model, "NuSVR", [("input", Int64TensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnNuSVRInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnNuSVRInt-Dec4")
 
     def test_convert_svr_bool(self):
         model, X = fit_regression_model(
             SVR(), is_bool=True)
         model_onnx = convert_sklearn(
-            model,
-            "SVR",
+            model, "SVR",
             [("input", BooleanTensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnSVRBool-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnSVRBool-Dec4")
 
     def test_convert_nusvr_bool(self):
         model, X = fit_regression_model(
             NuSVR(), is_bool=True)
         model_onnx = convert_sklearn(
-            model,
-            "NuSVR",
+            model, "NuSVR",
             [("input", BooleanTensorType([None, X.shape[1]]))],
-            target_opset=TARGET_OPSET
-        )
+            target_opset=TARGET_OPSET)
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnNuSVRBool",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')"
-        )
+            X, model, model_onnx,
+            basename="SklearnNuSVRBool")
 
     @unittest.skipIf(
         StrictVersion(onnx.__version__) < StrictVersion("1.4.1"),
@@ -537,18 +459,15 @@ class TestSklearnSVM(unittest.TestCase):
             model, "OCSVM", [("input", FloatTensorType([None, X.shape[1]]))],
             target_opset=TARGET_OPSET)
         dump_data_and_model(
-            X,
-            model,
-            model_onnx,
-            basename="SklearnBinOneClassSVM",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " < StrictVersion('0.5.0')")
+            X, model, model_onnx,
+            basename="SklearnBinOneClassSVM")
 
     def test_model_linear_svc_binary_class(self):
         model, X = self._fit_binary_classification(LinearSVC(max_iter=10000))
         model_onnx = convert_sklearn(
             model, "linear SVC",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -560,7 +479,8 @@ class TestSklearnSVM(unittest.TestCase):
         model, X = self._fit_multi_classification(LinearSVC(max_iter=10000))
         model_onnx = convert_sklearn(
             model, "linear SVC",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -572,7 +492,8 @@ class TestSklearnSVM(unittest.TestCase):
         model, X = self._fit_binary_classification(SVC(max_iter=10000))
         model_onnx = convert_sklearn(
             model, "linear SVC",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -585,7 +506,8 @@ class TestSklearnSVM(unittest.TestCase):
         model, X = self._fit_multi_classification(SVC(max_iter=10000))
         model_onnx = convert_sklearn(
             model, "linear SVC",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -599,7 +521,7 @@ class TestSklearnSVM(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "linear SVC",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options={'zipmap': False})
+            options={'zipmap': False}, target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -613,7 +535,7 @@ class TestSklearnSVM(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "linear SVC",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options={'zipmap': False})
+            options={'zipmap': False}, target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -625,7 +547,8 @@ class TestSklearnSVM(unittest.TestCase):
         model, X = self._fit_binary_classification(NuSVC(max_iter=10000))
         model_onnx = convert_sklearn(
             model, "linear SVC",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -639,7 +562,8 @@ class TestSklearnSVM(unittest.TestCase):
             NuSVC(max_iter=10000, nu=0.1))
         model_onnx = convert_sklearn(
             model, "linear SVC",
-            [("input", FloatTensorType([None, X.shape[1]]))])
+            [("input", FloatTensorType([None, X.shape[1]]))],
+            target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -653,7 +577,7 @@ class TestSklearnSVM(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "linear SVC",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options={'zipmap': False})
+            options={'zipmap': False}, target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
@@ -667,7 +591,7 @@ class TestSklearnSVM(unittest.TestCase):
         model_onnx = convert_sklearn(
             model, "linear SVC",
             [("input", FloatTensorType([None, X.shape[1]]))],
-            options={'zipmap': False})
+            options={'zipmap': False}, target_opset=TARGET_OPSET)
         sess = InferenceSession(model_onnx.SerializeToString())
         res = sess.run(None, {'input': X})
         label = model.predict(X)
